@@ -1080,6 +1080,8 @@ static void tangle_actor_allocate(ClutterActor* self, const ClutterActorBox* box
 	if (!old_allocation ||
 	    old_allocation->x1 != new_allocation->x1 || old_allocation->x2 != new_allocation->x2 ||
 	    old_allocation->y1 != new_allocation->y1 || old_allocation->y2 != new_allocation->y2) {
+		tangle_bufferer_mark_allocation_changed(self);
+
 		if (!old_allocation) {
 			TANGLE_ACTOR_SET_FLAGS(actor, TANGLE_ACTOR_SHOWING);
 			actor->priv->transition_scale_children = TRUE;
@@ -1415,6 +1417,8 @@ static void tangle_actor_dispose(GObject* object) {
 	
 	actor = TANGLE_ACTOR(object);
 
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->transition);
+	
 	if (actor->priv->hiding_timeline) {
 		complete_timeline(actor->priv->hiding_timeline);
 		g_object_unref(actor->priv->hiding_timeline);
@@ -1834,7 +1838,7 @@ static void clutter_scriptable_iface_init(ClutterScriptableIface* iface) {
 	iface->set_custom_property = tangle_actor_set_custom_property;
 }
 
-static void on_transition_timeline_completed(ClutterTimeline* timeline, gpointer user_data) {
+static gboolean emit_transition_completed(gpointer user_data) {
 	TangleVault* vault;
 	TangleActor* actor;
 	ClutterActorBox* from_allocation;
@@ -1849,6 +1853,8 @@ static void on_transition_timeline_completed(ClutterTimeline* timeline, gpointer
 	}
 	clutter_actor_box_free(from_allocation);
 	clutter_actor_box_free(to_allocation);
+
+	return FALSE;
 }
 
 static ClutterTimeline* animate_transition(TangleActor* actor, ClutterActorBox* from_allocation, ClutterActorBox* to_allocation) {
@@ -1856,15 +1862,12 @@ static ClutterTimeline* animate_transition(TangleActor* actor, ClutterActorBox*
 	TangleVault* vault;
 	
 	g_signal_emit(actor, signals[ANIMATE_TRANSITION], 0, from_allocation, to_allocation, &timeline);
+
+	vault = tangle_vault_new(3, TANGLE_TYPE_ACTOR, actor, CLUTTER_TYPE_ACTOR_BOX, from_allocation, CLUTTER_TYPE_ACTOR_BOX, to_allocation);
 	if (timeline) {
-		vault = tangle_vault_new(3, TANGLE_TYPE_ACTOR, actor, CLUTTER_TYPE_ACTOR_BOX, from_allocation, CLUTTER_TYPE_ACTOR_BOX, to_allocation);
-		tangle_signal_connect_vault(timeline, "completed", G_CALLBACK(on_transition_timeline_completed), vault);
+		tangle_signal_connect_vault_flags(timeline, "completed", G_CALLBACK(emit_transition_completed), vault, G_CONNECT_SWAPPED);
 	} else {
-		g_signal_emit(actor, signals[TRANSITION_COMPLETED], 0, from_allocation, to_allocation);
-		if (TANGLE_ACTOR_IS_SHOWING(actor)) {
-			g_signal_emit(actor, signals[SHOW_COMPLETED], 0, to_allocation);
-			TANGLE_ACTOR_UNSET_FLAGS(actor, TANGLE_ACTOR_SHOWING);
-		}
+		g_timeout_add(1, emit_transition_completed, vault);
 	}
 
 	return timeline;
