@@ -12,7 +12,6 @@
 
 #include <clutter/clutter.h>
 #include "tangle-widget.h"
-#include "tangle-action.h"
 
 #define TANGLE_TYPE_BUTTON (tangle_button_get_type ())
 #define TANGLE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TANGLE_TYPE_BUTTON, TangleButton))
@@ -70,4 +69,6 @@ void tangle_button_set_selected_background_actor(TangleButton* button, ClutterAc
 gboolean tangle_button_get_selected(TangleButton* button);
 void tangle_button_set_selected(TangleButton* button, gboolean selected);
 
+void tangle_button_stop_highlighting(TangleButton* button);
+
 #endif
