@@ -20,15 +20,21 @@
 #define TANGLE_DRAG_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), TANGLE_TYPE_DRAG_ACTION, TangleDragActionClass))
 
 typedef struct _TangleDragActionPrivate TangleDragActionPrivate;
+typedef struct _TangleDragAction TangleDragAction;
+typedef struct _TangleDragActionClass TangleDragActionClass;
 
-typedef struct _TangleDragAction {
+#include "tangle-drop-action.h"
+
+struct _TangleDragAction {
 	ClutterDragAction parent_instance;
 	TangleDragActionPrivate* priv;
-} TangleDragAction;
+};
 
-typedef struct _TangleDragActionClass {
+struct _TangleDragActionClass {
 	ClutterDragActionClass parent_class;
-} TangleDragActionClass;
+
+	void (*dropped)(TangleDragAction* drag_action, TangleDropAction* drop_action);
+};
 
 GType tangle_drag_action_get_type(void) G_GNUC_CONST;
 
