@@ -25,15 +25,14 @@ TangleLayout* tangle_stack_layout_new() {
 static void tangle_stack_layout_get_preferred_width(TangleLayout* layout, TangleWidget* widget, gfloat for_height, gfloat* min_width_p, gfloat* natural_width_p) {
 	gfloat max_min_width;
 	gfloat max_natural_width;
-	GList* child_in_list;
+	TangleActorIterator actor_iterator;
 	ClutterActor* actor;
 	gfloat actor_min_width;
 	gfloat actor_natural_width;
 
 	max_min_width = 0.0;
 	max_natural_width = 0.0;
-	for (child_in_list = tangle_widget_get_children_readonly(widget); child_in_list; child_in_list = child_in_list->next) {
-		actor = CLUTTER_ACTOR(child_in_list->data);
+	for (tangle_widget_initialize_actor_iterator(widget, &actor_iterator); (actor = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 		if (CLUTTER_ACTOR_IS_VISIBLE(actor)) {
 			tangle_layout_get_preferred_actor_width(layout, actor, for_height, &actor_min_width, &actor_natural_width);
 			if (actor_min_width > max_min_width) {
@@ -55,15 +54,14 @@ static void tangle_stack_layout_get_preferred_width(TangleLayout* layout, Tangle
 static void tangle_stack_layout_get_preferred_height(TangleLayout* layout, TangleWidget* widget, gfloat for_width, gfloat* min_height_p, gfloat* natural_height_p) {
 	gfloat max_min_height;
 	gfloat max_natural_height;
-	GList* child_in_list;
+	TangleActorIterator actor_iterator;
 	ClutterActor* actor;
 	gfloat actor_min_height;
 	gfloat actor_natural_height;
 
 	max_min_height = 0.0;
 	max_natural_height = 0.0;
-	for (child_in_list = tangle_widget_get_children_readonly(widget); child_in_list; child_in_list = child_in_list->next) {
-		actor = CLUTTER_ACTOR(child_in_list->data);
+	for (tangle_widget_initialize_actor_iterator(widget, &actor_iterator); (actor = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 		if (CLUTTER_ACTOR_IS_VISIBLE(actor)) {
 			tangle_layout_get_preferred_actor_height(layout, actor, for_width, &actor_min_height, &actor_natural_height);
 			if (actor_min_height > max_min_height) {
@@ -84,15 +82,14 @@ static void tangle_stack_layout_get_preferred_height(TangleLayout* layout, Tangl
 
 static void tangle_stack_layout_allocate(TangleLayout* layout, TangleWidget* widget, gfloat width, gfloat height, ClutterAllocationFlags flags) {
 	ClutterActorBox actor_box;
-	GList* child_in_list;
+	TangleActorIterator actor_iterator;
 	ClutterActor* actor;
 
 	actor_box.x1 = 0.0;
 	actor_box.y1 = 0.0;
 	actor_box.x2 = width;
 	actor_box.y2 = height;
-	for (child_in_list = tangle_widget_get_children_readonly(widget); child_in_list; child_in_list = child_in_list->next) {
-		actor = CLUTTER_ACTOR(child_in_list->data);
+	for (tangle_widget_initialize_actor_iterator(widget, &actor_iterator); (actor = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 		if (CLUTTER_ACTOR_IS_VISIBLE(actor)) {
 			tangle_layout_allocate_actor(layout, actor, &actor_box, flags);
 		}
