@@ -39,11 +39,14 @@ ClutterAction* tangle_stretch_action_new(ClutterActor* stretched_actor) {
 }
 
 ClutterActor* tangle_stretch_action_get_stretched_actor(TangleStretchAction* stretch_action) {
+	g_return_val_if_fail(TANGLE_IS_STRETCH_ACTION(stretch_action), NULL);
 
 	return stretch_action->priv->stretched_actor;
 }
 
 void tangle_stretch_action_set_stretched_actor(TangleStretchAction* stretch_action, ClutterActor* stretched_actor) {
+	g_return_if_fail(TANGLE_IS_STRETCH_ACTION(stretch_action));
+
 	if (stretch_action->priv->stretched_actor != stretched_actor) {
 		if (stretch_action->priv->stretched_actor) {
 			g_object_unref(stretch_action->priv->stretched_actor);
@@ -60,6 +63,8 @@ void tangle_stretch_action_set_stretched_actor(TangleStretchAction* stretch_acti
 }
 
 void tangle_stretch_action_get_min_size(TangleStretchAction* stretch_action, gfloat* min_width_return, gfloat* min_height_return) {
+	g_return_if_fail(TANGLE_IS_STRETCH_ACTION(stretch_action));
+
 	if (min_width_return) {
 		*min_width_return = stretch_action->priv->min_width;
 	}
@@ -69,6 +74,8 @@ void tangle_stretch_action_get_min_size(TangleStretchAction* stretch_action, gfl
 }
 
 void tangle_stretch_action_set_min_size(TangleStretchAction* stretch_action, gfloat min_width, gfloat min_height) {
+	g_return_if_fail(TANGLE_IS_STRETCH_ACTION(stretch_action));
+
 	if (stretch_action->priv->min_width = min_width) {
 		stretch_action->priv->min_width = min_width;
 		g_object_notify(G_OBJECT(stretch_action), "min-width");
@@ -80,6 +87,8 @@ void tangle_stretch_action_set_min_size(TangleStretchAction* stretch_action, gfl
 }
 
 void tangle_stretch_action_get_max_size(TangleStretchAction* stretch_action, gfloat* max_width_return, gfloat* max_height_return) {
+	g_return_if_fail(TANGLE_IS_STRETCH_ACTION(stretch_action));
+
 	if (max_width_return) {
 		*max_width_return = stretch_action->priv->max_width;
 	}
@@ -89,6 +98,8 @@ void tangle_stretch_action_get_max_size(TangleStretchAction* stretch_action, gfl
 }
 
 void tangle_stretch_action_set_max_size(TangleStretchAction* stretch_action, gfloat max_width, gfloat max_height) {
+	g_return_if_fail(TANGLE_IS_STRETCH_ACTION(stretch_action));
+
 	if (stretch_action->priv->max_width = max_width) {
 		stretch_action->priv->max_width = max_width;
 		g_object_notify(G_OBJECT(stretch_action), "max-width");
