@@ -27,10 +27,15 @@ G_DEFINE_TYPE_WITH_CODE(TangleWidget, tangle_widget, TANGLE_TYPE_ACTOR,
                         G_IMPLEMENT_INTERFACE(CLUTTER_TYPE_CONTAINER, clutter_container_iface_init);
 			G_IMPLEMENT_INTERFACE(TANGLE_TYPE_STYLABLE, tangle_stylable_iface_init));
 
+#if 0
+#define LOG_BUFFERING(x, y) g_print(x, y)
+#else
+#define LOG_BUFFERING(x, y)
+#endif
+
 enum {
 	PROP_0,
 	PROP_N_CHILDREN,
-	PROP_CHILREN_READONLY,
 	PROP_LAYOUT,
 	PROP_PADDING,
 	PROP_PADDING_SET,
@@ -50,6 +55,7 @@ enum {
 	PAINT_CHILDREN,
 	LAST_SIGNAL
 };
+
 struct _TangleWidgetPrivate {
 	GList* children;
 	TangleLayout* layout;
@@ -64,6 +70,8 @@ struct _TangleWidgetPrivate {
 	TangleActor* interacting_descendant;
 	TangleActor* dragging_descendant;
 	
+	guint revision;
+		
 	guint padding_set : 1;
 	guint background_color_set : 1;
 	guint prefer_background_size : 1;
@@ -136,12 +144,6 @@ gboolean tangle_widget_has_child(TangleWidget* widget, ClutterActor* actor) {
 	return g_list_find(widget->priv->children, actor) != NULL;
 }
 
-GList* tangle_widget_get_children_readonly(TangleWidget* widget) {
-	g_return_val_if_fail(TANGLE_IS_WIDGET(widget), NULL);
-
-	return widget->priv->children;
-}
-
 void tangle_widget_foreach_swapped(TangleWidget* widget, TangleSwappedCallback swapped_callback, gpointer user_data) {
 	GList* child_in_list;
 
@@ -331,8 +333,6 @@ void tangle_widget_set_background_actor(TangleWidget* widget, ClutterActor* acto
 		widget->priv->background_actor = actor;
 		
 		if (actor) {
-			tangle_actor_get_aligned_allocation(TANGLE_ACTOR(widget), &actor_box);
-			clutter_actor_allocate(actor, &actor_box, CLUTTER_ABSOLUTE_ORIGIN_CHANGED);
 			clutter_actor_push_internal(CLUTTER_ACTOR(widget));
 			clutter_actor_set_parent(actor, CLUTTER_ACTOR(widget));	
 			clutter_actor_pop_internal(CLUTTER_ACTOR(widget));
@@ -366,8 +366,6 @@ void tangle_widget_change_background_actor(TangleWidget* widget, ClutterActor* a
 		widget->priv->background_actor = actor;
 		
 		if (actor) {
-			tangle_actor_get_aligned_allocation(TANGLE_ACTOR(widget), &actor_box);
-			clutter_actor_allocate(actor, &actor_box, CLUTTER_ABSOLUTE_ORIGIN_CHANGED);
 			widget->priv->background_parented = FALSE;
 		}
 		
@@ -395,8 +393,6 @@ void tangle_widget_set_foreground_actor(TangleWidget* widget, ClutterActor* acto
 		widget->priv->foreground_actor = actor;
 		
 		if (actor) {
-			tangle_actor_get_aligned_allocation(TANGLE_ACTOR(widget), &actor_box);
-			clutter_actor_allocate(actor, &actor_box, CLUTTER_ABSOLUTE_ORIGIN_CHANGED);
 			clutter_actor_push_internal(CLUTTER_ACTOR(widget));
 			clutter_actor_set_parent(actor, CLUTTER_ACTOR(widget));	
 			clutter_actor_pop_internal(CLUTTER_ACTOR(widget));
@@ -488,7 +484,6 @@ gboolean tangle_widget_get_descendant_dragging(TangleWidget* widget) {
 	return widget->priv->dragging_descendant != NULL;
 }
 
-
 #define ABS_F(x) ((x) < 0 ? -(x) : (x))
 
 void tangle_widget_clamp_child_boundaries(TangleWidget* widget, TangleClamp* clamp) {
@@ -497,7 +492,7 @@ void tangle_widget_clamp_child_boundaries(TangleWidget* widget, TangleClamp* cla
 	GList* child_in_list;
         ClutterActor* actor;
         ClutterActorBox actor_box;
-	gfloat child_value;
+	gfloat child_value, end_value;
 	gfloat child_distance;
 	gfloat clamp_distance = G_MAXFLOAT;
 	
@@ -517,50 +512,88 @@ void tangle_widget_clamp_child_boundaries(TangleWidget* widget, TangleClamp* cla
 
 		if (direction == TANGLE_CLAMP_HORIZONTAL) {
 			child_value = actor_box.x1;
+			end_value = actor_box.x2;
 		} else {
 			child_value = actor_box.y1;
+			end_value = actor_box.y2;
 		}
 		if ((child_distance = ABS_F(child_value - original_value)) < clamp_distance) {
 			clamp_distance = child_distance;
 			tangle_clamp_set_clamped_value(clamp, child_value);
 		}
+		if ((child_distance = ABS_F(end_value - original_value)) < clamp_distance) {
+			clamp_distance = child_distance;
+			tangle_clamp_set_clamped_value(clamp, end_value);
+		}
 	}
 }
 
-static void paint_actor_if_mapped(ClutterActor* actor) {
+void tangle_widget_initialize_actor_iterator(TangleWidget* widget, TangleActorIterator* actor_iterator) {
+	g_return_if_fail(TANGLE_IS_WIDGET(widget));
+
+	actor_iterator->widget = widget;
+	actor_iterator->revision = widget->priv->revision;
+	actor_iterator->children = widget->priv->children;
+}
+	
+ClutterActor* tangle_actor_iterator_get_actor(TangleActorIterator* actor_iterator) {
+	ClutterActor* actor = NULL;
+	
+	g_return_val_if_fail(TANGLE_IS_WIDGET(actor_iterator->widget), NULL);
+	g_return_val_if_fail(actor_iterator->revision == actor_iterator->widget->priv->revision, NULL);
+	
+	if (actor_iterator->children) {
+		actor = CLUTTER_ACTOR(actor_iterator->children->data);
+	}
+	
+	return actor;
+}
+
+void tangle_actor_iterator_next(TangleActorIterator* actor_iterator) {
+	g_return_if_fail(TANGLE_IS_WIDGET(actor_iterator->widget));
+	g_return_if_fail(actor_iterator->revision == actor_iterator->widget->priv->revision);
+
+	actor_iterator->children = actor_iterator->children->next;	
+}
+
+static void paint_actor(gpointer data, gpointer user_data) {
+	TangleWidget* widget;
+	ClutterActor* actor;
+
+	widget = TANGLE_WIDGET(user_data);
+	actor = CLUTTER_ACTOR(data);
+	
 	if (CLUTTER_ACTOR_IS_MAPPED(actor)) {
 		clutter_actor_paint(actor);
 	}
 }
 
 static void tangle_widget_paint_children(TangleWidget* widget) {
-	g_list_foreach(widget->priv->children, (GFunc)paint_actor_if_mapped, NULL);
+	g_list_foreach(widget->priv->children, paint_actor, widget);
 }
 
-static void tangle_widget_paint(ClutterActor* actor) {
+static void tangle_widget_paint_aligned(TangleActor* actor, gfloat width, gfloat height) {
 	TangleWidget* widget;
+	gboolean transition_scale_children;
+	guint8 alpha;
 	gdouble scale_x;
 	gdouble scale_y;
 	gfloat scale_center_x;
 	gfloat scale_center_y;
-	guint8 alpha;
-	ClutterActorBox box;
-	gboolean transition_scale_children;
 	
 	widget = TANGLE_WIDGET(actor);
-	transition_scale_children = tangle_actor_should_transition_scale_children(TANGLE_ACTOR(widget));
 
 	cogl_push_matrix();
 	tangle_actor_apply_transition_scale(TANGLE_ACTOR(widget));
+	transition_scale_children = tangle_actor_should_transition_scale_children(TANGLE_ACTOR(widget));
 
 	if (widget->priv->background_color_set) {
-		alpha = clutter_actor_get_paint_opacity(actor) * widget->priv->background_color.alpha / 255;
+		alpha = clutter_actor_get_paint_opacity(CLUTTER_ACTOR(widget)) * widget->priv->background_color.alpha / 255;
 		cogl_set_source_color4ub(widget->priv->background_color.red,
 			 		 widget->priv->background_color.green,
 			 		 widget->priv->background_color.blue,
 					 alpha);
-		tangle_actor_get_aligned_allocation(TANGLE_ACTOR(actor), &box);
-		cogl_rectangle(box.x1, box.y1, box.x2, box.y2);
+		cogl_rectangle(0, 0, width, height);
 	}
 	if (widget->priv->background_actor) {
 		clutter_actor_paint(widget->priv->background_actor);
@@ -572,18 +605,19 @@ static void tangle_widget_paint(ClutterActor* actor) {
 
 	g_signal_emit(widget, signals[PAINT_CHILDREN], 0);
 
+	if (!transition_scale_children) {
+		cogl_push_matrix();
+	}
+
 	if (widget->priv->foreground_actor) {
 		if (!transition_scale_children) {
-			cogl_push_matrix();
 			tangle_actor_apply_transition_scale(TANGLE_ACTOR(widget));
 		}
 		
 		clutter_actor_paint(widget->priv->foreground_actor);
-		
-		cogl_pop_matrix();
-	} else if (transition_scale_children) {
-		cogl_pop_matrix();
 	}
+	
+	cogl_pop_matrix();
 }
 
 static void paint_actor_if_mapped_and_not_hiding_or_showing(ClutterActor* actor) {
@@ -960,7 +994,6 @@ static void tangle_widget_class_init(TangleWidgetClass* widget_class) {
 	gobject_class->set_property = tangle_widget_set_property;
 	gobject_class->get_property = tangle_widget_get_property;
 
-	clutter_actor_class->paint = tangle_widget_paint;
 	clutter_actor_class->pick = tangle_widget_pick;
 	clutter_actor_class->allocate = tangle_widget_allocate;
 	clutter_actor_class->map = tangle_widget_map;
@@ -968,6 +1001,7 @@ static void tangle_widget_class_init(TangleWidgetClass* widget_class) {
 
 	actor_class->get_preferred_width = tangle_widget_get_preferred_width;
 	actor_class->get_preferred_height = tangle_widget_get_preferred_height;
+	actor_class->paint_aligned = tangle_widget_paint_aligned;
 
 	widget_class->paint_children = tangle_widget_paint_children;
 	widget_class->allocate_children = tangle_widget_allocate_children;
